@@ -3,7 +3,7 @@ Whitelisting HTML scrubber.
 """
 
 __author__ = "Samuel Stauffer <samuel@descolada.com>"
-__version__ = "1.1"
+__version__ = "1.1.1"
 __license__ = "Python"
 
 # 
@@ -11,7 +11,7 @@ __license__ = "Python"
 #   http://www.feedparser.org/docs/html-sanitization.html
 #
 
-import re
+import re, string
 from urlparse import urljoin
 from itertools import chain
 from BeautifulSoup import BeautifulSoup
